@@ -8,6 +8,8 @@ use Elive::Entity;
 use base qw{ Elive::Entity };
 
 use SOAP::Lite;  # contains SOAP::Data package
+use MIME::Types;
+use File::Basename qw{};
 
 =head1 NAME
 
@@ -64,14 +66,15 @@ has 'data' => (is => 'rw', isa => 'Str',
     my $preload = Elive::Entity::Preload->upload(
              {
 		    type => 'whiteboard',
-		    mimeType => 'application/octet-stream',
 		    name => 'introduction.wbd',
 		    ownerId => 357147617360,
                     data => $binary_data,
 	     },
          );
 
-Upload data from a client and create a preload..
+Upload data from a client and create a preload.  If a c<mimeType> is not
+supplied, it will be guessed from the extension, using MIME::Types. 
+
 
 =cut
 
@@ -84,8 +87,15 @@ sub upload {
 
     my $length = length($binary_data) ||0;
 
-    $opt{param} = {length => $length}
-    if $length;
+    $opt{param}{length} = $length
+        if $length;
+
+    if ($insert_data->{name}) {
+	$insert_data->{mimeType} ||= $class->_guess_mimetype($insert_data->{name});
+	$insert_data->{type} ||= $insert_data->{name} =~ m{\.wbd}i
+	    ? 'whiteboard'
+	    : 'media';
+    }
 
     my $self = $class->SUPER::_insert_class($insert_data, %opt);
 
@@ -142,27 +152,41 @@ sub download {
     return undef;
 }
 
-=head2 import_file
+=head2 import_from_server
 
-    my $preload1 = Elive::Entity::Preload->import_file(
+    my $preload1 = Elive::Entity::Preload->import_from_server(
              {
 		    type => 'whiteboard',
-		    mimeType => 'application/octet-stream',
 		    name => 'introduction.wbd',
 		    ownerId => 357147617360,
                     fileName => $path_on_server
 	     },
          );
 
-Create a preload from a file that is already present on the server.
+Create a preload from a file that is already present on the server. If
+a c<mimeType> is not supplied, it will be guessed from the extension,
+using MIME::Types.
 
 =cut
 
-sub import_file {
+sub import_from_server {
     my $class = shift;
     my $insert_data = shift;
     my %opt = @_;
 
+    my $filename = delete $insert_data->{fileName};
+
+    die "missing fileName parameter"
+	unless $filename;
+
+    $insert_data->{mimeType} ||= $class->_guess_mimetype($filename);
+    $insert_data->{type} ||= $filename =~ m{\.wbd}i
+	    ? 'whiteboard'
+	    : 'media';
+    $insert_data->{name} ||= File::Basename::basename($filename);
+
+    $opt{param}{fileName} = $filename;
+
     $class->SUPER::_insert_class($insert_data,
 				 adapter => 'importPreload',
 				 %opt);
@@ -214,4 +238,23 @@ sub _hex_encode {
     return $data;
 }
 
+our $mime_types;
+
+sub _guess_mimetype {
+    my $class = shift;
+    my $filename = shift;
+
+    $mime_types ||= MIME::Types->new;
+
+    my $mime_type = $mime_types->mimeTypeOf($filename);
+
+    my $guess;
+    $guess = $mime_type->type
+	if $mime_type;
+
+    $guess ||= 'application/octet-stream';
+
+    return $guess;
+}
+
 1;
